% This code needs data_*_*.mat file as an input
% This contains ['un','vn','xn','yn'] denote flow fields and their locations 
% and ['xcn','ycn'] denote interface data

clear all
clc

%%%%%%%%%%%%%%%%%%% Input %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n = input('Please enter a number from 500,100,20 and 10: ');

switch n
    case 500
        load("data_500cst_500microns.mat")
    case 100
        load("data_100cst_500microns.mat")
    case 20
        load("data_20cst_150microns.mat")
    case 10
        load("data_10cst_150microns.mat")
    otherwise
        disp('Please enter a valid number')
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% For skipping points from the bulk to better visibility

iskip=1;
jskip=1;

h1=figure(1) 
clf;

hold on

lv=2; % length of vector

% Plotting vector fields

quiver(xn(1:iskip:end,1:jskip:end),yn(1:iskip:end,1:jskip:end),...
    un(1:iskip:end,1:jskip:end),vn(1:iskip:end,1:jskip:end),lv,'k')


fs=16;

plot(xcn,ycn,'-r','Linewidth',3)    % plotting interface shape

pos=[-0.1  -2.5  0.09 4]

rectangle('Position',pos,'FaceColor',[0.8 .8 .8])   % Plotting rectangle


xlabel( '$x$(mm)','FontSize',fs,'FontName','Times New Roman','Interpreter','latex')
ylabel( '$y$(mm)','FontSize',fs,'FontName','Times New Roman','Interpreter','latex')

set(gcf,'color','w');   

set(gca,'XMinorTick','on','YMinorTick','on','TickDir','in')

set(gca,'TickLength',[0.02,0.01])

set(gca,'Fontsize',fs,'Fontname','Times New Roman')

annotation(h1,'arrow',[0.28 0.28],...
    [0.63 0.44]);


grid on
box on

axis equal

ylim([-2 0.5])
xlim([-0.3 2])


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%% Finished %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


